@@ -4,6 +4,7 @@
 
 from packagesample import __version__, log, modules
 import argparse
+import __builtin__
 
 
 def main():
@@ -39,7 +40,7 @@ def main():
         action="store_true")
 
     args = parser.parse_args()  # if required params arent met, program aborts
-    __chicken__ = args.chicken
+    __builtin__.chicken = args.chicken
 
     try:
         result = eval(args.task + '.main()')
