@@ -3,10 +3,11 @@ from flask import Flask, render_template
 from flask.ext.bootstrap import Bootstrap
 from packagesample import __version__, log
 from packagesample.modules import *
+import __builtin__
 
 app = Flask(__name__)
 Bootstrap(app)
-
+__builtin__.chicken = False
 
 @app.context_processor
 def get_title():
